# Procédure d'installation

## Installation

Éditez le fichier *dependencies.json* afin de définir les paramètres de votre installation.

Les variables à modifier pour l’installation sont :

````eval_rst

+-----------------------+--------------------------------------------------------------------------------------------------------+
| Variable              |     Description                                                                                        |
+=======================+========================================================================================================+
|   API_ALIAS           | Alias pour accéder à l'API de VMAP2 (par défaut : /rest)                                               |
+-----------------------+--------------------------------------------------------------------------------------------------------+
|   APP_ALIAS           | Alias pour accéder au client de VMAP2                                                                  |
+-----------------------+--------------------------------------------------------------------------------------------------------+
|   WMS_ALIAS           | Alias pour accéder à Mapserver                                                                         |
+-----------------------+--------------------------------------------------------------------------------------------------------+
|   HOSTNAME            | Adresse de la machine accèssible depuis un navigateur web                                              |
+-----------------------+--------------------------------------------------------------------------------------------------------+
|   HTTPSERVER_PATH     | Chemin jusqu'au répertoire d'Apache24 (C:/.../Apache24/conf pour windows et /etc/apache2 pour linux)   |
+-----------------------+--------------------------------------------------------------------------------------------------------+
|   INSTALL_PATH        | Répertoire d'installation (/var/www/vmap2 préférable pour Linux C:/server/vmap2 conseillé pour Windows)|
+-----------------------+--------------------------------------------------------------------------------------------------------+
|   POSTGRES_HOST       | Serveur de la base de données                                                                          |
+-----------------------+--------------------------------------------------------------------------------------------------------+
|   POSTGRES_PORT       | Port d'accès à la base de données                                                                      |
+-----------------------+--------------------------------------------------------------------------------------------------------+
|   POSTGRES_DB         | Nom de la base de données (La base de données peut être existante)                                     |
+-----------------------+--------------------------------------------------------------------------------------------------------+
|   POSTGRES_USER       | Compte d'un superutilisateur de la base                                                                |
+-----------------------+--------------------------------------------------------------------------------------------------------+
|   POSTGRES_PASSWORD   | Mot de passe du compte superutilisateur                                                                |
+-----------------------+--------------------------------------------------------------------------------------------------------+

````

Dans la section **application** il est possible de définir les utilisateurs qui seront insérés lors de l'installation dans le tableau **users**.

```js
{
  ...
  "application" : {
    ...
    "users": {
      "admin": {
        "grouproles": [
          "vitis_user",
          "vitis_admin"
        ],
        "login": true,
        "password": "admin",
        "roles": [
          "LOGIN",
          "CREATEROLE"
        ]
      }
    }
  }
}
```

Les clés dans *users* seront utilisées comme identifiants. En fonction des informations associées, l'utilisateur aura plus ou moins de droits :
- **grouproles** : permet de définir des privilèges qui seront associés à l'utilisateur
- **login** : boolean permettant de se connecter à la base ainsi qu'à l'application
- **password** : mot de passe de l'utilisateur
- **roles** : roles de l'utilisateur dans postgres

L’installateur assure les opérations suivantes :
- Copie du code du serveur d’application
- Copie du code du moteur
- Installation et configuration de l'exécutable JobsRunner comme un service
- Installation de PHP et de PhantomJS
- Configuration du serveur HTTPS Apache
- Création de la base de données dans PostgreSQL
- Création d’un compte administrateur dans PostgreSQL
- Nettoyage des caches

---

## Test de l'installation de VMAP2

L'instance de VMAP2 doit désormais être disponible à l’adresse **https://[serveur]/[alias]**

- **\[serveur\]** : l’adresse de la machine où vous avez installé l’application (*HOSTNAME*)
- **\[alias\]** : la clé que vous avez saisie dans le fichier de configuration (*APP_ALIAS*)

Si vous vous connectez avec le protocole HTTP, la connexion sera automatiquement redirigée vers HTTPS.

Si vous avez créé vous-même votre propre certificat, votre serveur n’est pas sécurisé et votre navigateur va sans doute afficher un message d’alerte.

Vous devrez créer une exception de sécurité dans votre navigateur avant de pouvoir accéder à votre site.

Si vous utilisez un certificat valide ou si vous avez créé une exception de sécurité, vous devez arriver à la page de connexion.

Vous pouvez vous connecter en utilisant le compte et le mot de passe définis lors de l’installation.
